@@ -8,16 +8,14 @@ use warnings;
 use Data::Object;
 use Readonly;
 
-our $VERSION = '0.02'; # VERSION
+our $VERSION = '0.03'; # VERSION
 
 sub new {
-    my $class = shift;
-    my $data  = shift;
-    my $self  = Data::Object->new($data);
-    my $type  = $self->objtype;
+    my $self = Data::Object->new(pop);
+    my $type = $self->objtype;
 
-    if    ('HASH'  eq $type) { Readonly::Hash   %$self => %$self; }
-    elsif ('ARRAY' eq $type) { Readonly::Array  @$self => @$self; }
+    if    ($type eq 'HASH')  { Readonly::Hash   %$self => %$self; }
+    elsif ($type eq 'ARRAY') { Readonly::Array  @$self => @$self; }
     else                     { Readonly::Scalar $$self => $$self; }
 
     return $self;
@@ -37,7 +35,7 @@ Data::Object::Immutable - Immutable Data Type Objects for Perl 5
 
 =head1 VERSION
 
-version 0.02
+version 0.03
 
 =head1 SYNOPSIS
 
@@ -53,7 +51,10 @@ version 0.02
 =head1 DESCRIPTION
 
 Data::Object::Immutable provides a mechanism for making any L<Data::Object>
-data type object immutable. B<Note: This is an early release available for
+data type object immutable. An immutable object is an object whose state cannot
+be modified after it is created; Immutable objects are often useful because
+they are inherently thread-safe, easier to reason about, and offer higher
+security than mutable objects. B<Note: This is an early release available for
 testing and feedback and as such is subject to change.>
 
 =head1 AUTHOR
